api.cases.v2.test_helpers.service package — Argus-Toolbelt 1.0 documentation

# api.cases.v2.test_helpers.service package

## Submodules

## api.cases.v2.test_helpers.service.create_service module

`api.cases.v2.test_helpers.service.create_service.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/cases/v2/service, respond with HTTP 403

`api.cases.v2.test_helpers.service.create_service.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/cases/v2/service, respond with HTTP 404

`api.cases.v2.test_helpers.service.create_service.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/cases/v2/service, respond with HTTP 200

`api.cases.v2.test_helpers.service.create_service.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/cases/v2/service, respond with HTTP 401

## api.cases.v2.test_helpers.service.get_service module

`api.cases.v2.test_helpers.service.get_service.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/cases/v2/service/w+, respond with HTTP 403

`api.cases.v2.test_helpers.service.get_service.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/cases/v2/service/w+, respond with HTTP 404

`api.cases.v2.test_helpers.service.get_service.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/cases/v2/service/w+, respond with HTTP 200

`api.cases.v2.test_helpers.service.get_service.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/cases/v2/service/w+, respond with HTTP 401

## api.cases.v2.test_helpers.service.list_services module

`api.cases.v2.test_helpers.service.list_services.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/cases/v2/service, respond with HTTP 403

`api.cases.v2.test_helpers.service.list_services.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/cases/v2/service, respond with HTTP 404

`api.cases.v2.test_helpers.service.list_services.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/cases/v2/service, respond with HTTP 200

`api.cases.v2.test_helpers.service.list_services.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/cases/v2/service, respond with HTTP 401

## api.cases.v2.test_helpers.service.search_services module

`api.cases.v2.test_helpers.service.search_services.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/cases/v2/service/search, respond with HTTP 403

`api.cases.v2.test_helpers.service.search_services.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/cases/v2/service/search, respond with HTTP 404

`api.cases.v2.test_helpers.service.search_services.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/cases/v2/service/search, respond with HTTP 200

`api.cases.v2.test_helpers.service.search_services.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/cases/v2/service/search, respond with HTTP 401

## api.cases.v2.test_helpers.service.update_service module

`api.cases.v2.test_helpers.service.update_service.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/cases/v2/service/w+, respond with HTTP 403

`api.cases.v2.test_helpers.service.update_service.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/cases/v2/service/w+, respond with HTTP 404

`api.cases.v2.test_helpers.service.update_service.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/cases/v2/service/w+, respond with HTTP 200

`api.cases.v2.test_helpers.service.update_service.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/cases/v2/service/w+, respond with HTTP 401

## Module contents